<?php
// Include the database connection file
include '../../includes/connection.php';

// Initialize response array
$response = array("status" => "error", "message" => "An unknown error occurred.");

// Log the received data for debugging
file_put_contents('debug_log.txt', "Received POST data:\n" . print_r($_POST, true) . "\n", FILE_APPEND);

// Retrieve POST data
$buyer_email = isset($_POST['email']) ? $_POST['email'] : '';
$amount1 = isset($_POST['amount1']) ? $_POST['amount1'] : '0';
$company_name = "SigniFX"; // Your company name
$name = "Customer"; // Default name, can be set from your database or input

// Remove decimal part of amount1
$amount1 = intval(floatval($amount1)); // Convert to float and then to integer

// Check if amount1 matches with a plan in the Plans table
$amount_check_query = $conn->prepare("SELECT plan_name, duration_days FROM Plans WHERE price = ? AND plan_status = 'Active'");
if (!$amount_check_query) {
    file_put_contents('error_log.txt', "Database prepare error (amount_check_query): " . $conn->error . "\n", FILE_APPEND);
    $response["message"] = "Database prepare error.";
    echo json_encode($response);
    exit();
}
$amount_check_query->bind_param('d', $amount1);
$amount_check_query->execute();
$amount_check_query->bind_result($plan_name, $plan_duration);
$amount_check_query->fetch();
$amount_check_query->close();

if (!$plan_name) {
    file_put_contents('error_log.txt', "No matching plan found for amount $amount1.\n", FILE_APPEND);
    $response["message"] = "No matching plan found.";
    echo json_encode($response);
    exit();
}

// Calculate the purchase and expired dates
$purchase_date = date('Y-m-d'); // Current date in yyyy-mm-dd format
$expired_date_timestamp = strtotime("+$plan_duration days", strtotime($purchase_date));
$expired_date = date('Y-m-d', $expired_date_timestamp);

// Check if the buyer email exists in the Users table
$email_check_query = $conn->prepare("SELECT id FROM Users WHERE email = ?");
if (!$email_check_query) {
    file_put_contents('error_log.txt', "Database prepare error (email_check_query): " . $conn->error . "\n", FILE_APPEND);
    $response["message"] = "Database prepare error.";
    echo json_encode($response);
    exit();
}
$email_check_query->bind_param('s', $buyer_email);
$email_check_query->execute();
$email_check_query->bind_result($user_id);
$email_check_query->fetch();
$email_check_query->close();

if ($user_id) {
    // Update the Users table
    $update_user_query = $conn->prepare("UPDATE Users SET user_type = ?, plan_duration = ?, purchase_date = ?, expired_date = ? WHERE id = ?");
    if (!$update_user_query) {
        file_put_contents('error_log.txt', "Database prepare error (update_user_query): " . $conn->error . "\n", FILE_APPEND);
        $response["message"] = "Database prepare error.";
        echo json_encode($response);
        exit();
    }
    $update_user_query->bind_param('ssssi', $plan_name, $plan_duration, $purchase_date, $expired_date, $user_id);
    
    if (!$update_user_query->execute()) {
        file_put_contents('error_log.txt', "Failed to update user data: " . $update_user_query->error . "\n", FILE_APPEND);
        $response["message"] = "Failed to update user data.";
        echo json_encode($response);
        exit();
    }
    $update_user_query->close();
    file_put_contents('debug_log.txt', "User data updated successfully.\n", FILE_APPEND);

// Prepare HTML email
$message = "
<html>
    <head>
        <style>
            body {
                font-family: Arial, sans-serif;
                color: #333;
                line-height: 1.6;
                margin: 20px;
            }
            .container {
                max-width: 600px;
                margin: 0 auto;
                padding: 20px;
                border: 1px solid #ddd;
                border-radius: 5px;
                background-color: #f9f9f9;
            }
            h1 {
                color: #0056b3;
            }
            p {
                margin: 10px 0;
            }
            .footer {
                margin-top: 20px;
                font-size: 0.9em;
                color: #777;
            }
            a {
                color: #0056b3;
                text-decoration: none;
            }
        </style>
    </head>
    <body>
        <div class='container'>
            <h1>Hello $name,</h1>
            <p>We are excited to welcome you to <strong>$company_name</strong>!</p>
            <p>Your free subscription plan has been successfully activated. You can now enjoy all the features and benefits that come with it.</p>
            <p>We encourage you to explore our services and make the most of your subscription. If you ever decide to upgrade your plan, we have various options available that provide even more value.</p>
            <p>If you have any questions or require assistance, please don't hesitate to reach out to our support team. We are here to help!</p>
            <p class='footer'>Thank you for choosing $company_name.<br>Best regards,<br>The $company_name Team</p>
        </div>
    </body>
</html>
";

    
    // Send email
    $encoded_message = urlencode($message);
    $send_email_url = "https://deentime.app/mail/send.php?sender_name=" . urlencode($company_name) . "&subject=" . urlencode("Free Plan Activation Successfully") . "&receiver_email=" . urlencode($buyer_email) . "&message=" . $encoded_message;

    // Send the email
    $email_response = file_get_contents($send_email_url);
    file_put_contents('debug_log.txt', "Email sent to $buyer_email.\n", FILE_APPEND);

    $response["status"] = "success";
    $response["message"] = "Free plan activated successfully.";
} else {
    $response["message"] = "User email not found.";
}

// Output JSON response
header('Content-Type: application/json');
echo json_encode($response);

// Close the database connection
$conn->close();
file_put_contents('debug_log.txt', "Database connection closed.\n", FILE_APPEND);
?>
